@@ -134,8 +134,10 @@ class Game(object):
         # be voided by a move is uniquely determined by the starting index
         # of the move - regardless of what piece moves from that position
         # (excluding chess variants like chess960).
-        void_set = {0: 'q', 4: 'kq', 7: 'k',
-                    56: 'Q', 60: 'KQ', 63: 'K'}.get(start, '')
+        rights_map = {0: 'q', 4: 'kq', 7: 'k',
+                      56: 'Q', 60: 'KQ', 63: 'K'}
+        void_set = ''.join([rights_map.get(start, ''),
+                           rights_map.get(end, '')])
         new_rights = [r for r in self.state.rights if r not in void_set]
         fields[1] = ''.join(new_rights) or '-'
 
